# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.0.2

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.1...c0f24dfeeffc388ba8f2b27048c38c5466bf2026))

### Bugs fixed

- Fix update propagation logic [#2](https://github.com/trungleduc/ipecharts/pull/2) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-06-15&to=2024-06-16&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-06-15..2024-06-16&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.0.1

([Full Changelog](https://github.com/trungleduc/ipecharts/compare/v1.0.0...fd747d36fdf184c884f46f1381806e6e6be549c4))

### Enhancements made

- Bump frontend version [#1](https://github.com/trungleduc/ipecharts/pull/1) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/trungleduc/ipecharts/graphs/contributors?from=2024-06-15&to=2024-06-15&type=c))

[@trungleduc](https://github.com/search?q=repo%3Atrungleduc%2Fipecharts+involves%3Atrungleduc+updated%3A2024-06-15..2024-06-15&type=Issues)

## 1.0.0

No merged PRs
